/**
 * Builder component
 * @class ApBuilder
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _ap_builder_editor = require('./ap_builder_editor');

var _ap_builder_editor2 = _interopRequireDefault(_ap_builder_editor);

var _ap_builder_frame = require('./ap_builder_frame');

var _ap_builder_frame2 = _interopRequireDefault(_ap_builder_frame);

var _asleep = require('asleep');

var _asleep2 = _interopRequireDefault(_asleep);

var _apemanReactSpinner = require('apeman-react-spinner');

var _apemanReactTab = require('apeman-react-tab');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var noop = function noop() {
  return undefined;
};

/** @lends ApBuilder */
var ApBuilder = _react2.default.createClass({
  displayName: 'ApBuilder',


  // --------------------
  // Specs
  // --------------------

  propTypes: {
    /** Html contents */
    html: _react.PropTypes.string.isRequired,
    /** Script text */
    script: _react.PropTypes.string,
    /** Global variables */
    globals: _react.PropTypes.object,
    /** Compile script before executing */
    compile: _react.PropTypes.func,
    /** Handle html edit */
    onHtmlEdit: _react.PropTypes.func,
    /** Handle script edit */
    onScriptEdit: _react.PropTypes.func,
    /** Handle script error */
    onScriptError: _react.PropTypes.func,
    /** Labels */
    labels: _react.PropTypes.object,
    /** Errors */
    errors: _react.PropTypes.object,
    /** Codemirror mode for html */
    htmlMode: _react.PropTypes.string,
    /** Codemirror mode for script */
    scriptMode: _react.PropTypes.string,
    /** Custom actions for html editor */
    htmlActions: _react.PropTypes.array,
    /** Custom actions for script editor */
    scriptActions: _react.PropTypes.array,
    /** Check if supported */
    isSupported: _react.PropTypes.func
  },

  mixins: [],

  statics: {},

  getInitialState: function getInitialState() {
    var s = this;
    return {
      tab: null,
      overlaying: false,
      edittingHtml: '',
      edittingScript: '',
      vr: 0,
      spinning: false,
      htmlActions: [],
      scriptActions: []
    };
  },
  getDefaultProps: function getDefaultProps() {
    return {
      html: '',
      script: '',
      onHtmlEdit: noop,
      onScriptEdit: noop,
      labels: {
        htmlTab: 'HTML',
        scriptTab: 'Script'
      },
      htmlMode: 'htmlmixed',
      scriptMode: 'javascript',
      isSupported: function isSupported() {
        return (/Chrome/.test(navigator.userAgent)
        );
      }
    };
  },
  render: function render() {
    var s = this;
    var state = s.state;
    var props = s.props;
    var labels = props.labels;
    var html = props.html;
    var script = props.script;
    var compile = props.compile;
    var tab = state.tab;
    var overlaying = state.overlaying;
    var edittingScript = state.edittingScript;
    var edittingHtml = state.edittingHtml;

    var overlayClassName = (0, _classnames2.default)('ap-builder-overlay', {
      'ap-builder-overlay-enabled': overlaying
    });
    return _react2.default.createElement(
      'div',
      { className: (0, _classnames2.default)('ap-builder', props.className),
        style: Object.assign({}, props.style) },
      _react2.default.createElement(
        'div',
        { className: 'ap-builder-inner' },
        props.children,
        _react2.default.createElement(_ap_builder_frame2.default, { src: html,
          onLoad: s.handleHtmlLoad,
          onScriptError: props.onScriptError,
          script: script,
          compile: compile,
          vr: state.vr,
          globals: props.globals
        })
      ),
      _react2.default.createElement(
        _apemanReactTab.ApTabGroup,
        { className: overlayClassName },
        _react2.default.createElement(
          _apemanReactTab.ApTab,
          { className: 'ap-builder-tab' },
          s._renderTabItem('HTML', labels.htmlTab),
          s._renderTabItem('SCRIPT', labels.scriptTab)
        ),
        _react2.default.createElement(
          _apemanReactTab.ApTabContent,
          { selected: tab === 'HTML' },
          _react2.default.createElement(_ap_builder_editor2.default, { src: edittingHtml,
            mode: props.htmlMode,
            onChange: s.handleEditorChange,
            onSubmit: s.handleEditorSubmit,
            onCancel: s.handleEditCancel,
            actions: props.htmlActions
          })
        ),
        _react2.default.createElement(
          _apemanReactTab.ApTabContent,
          { selected: tab === 'SCRIPT' },
          _react2.default.createElement(_ap_builder_editor2.default, { src: edittingScript,
            mode: props.scriptMode,
            onChange: s.handleEditorChange,
            onSubmit: s.handleEditorSubmit,
            onCancel: s.handleEditCancel,
            actions: props.scriptActions
          })
        )
      ),
      _react2.default.createElement(_apemanReactSpinner.ApSpinner, { className: 'ap-builder-spinner',
        size: 'xx-large',
        enabled: state.spinning
      })
    );
  },


  // --------------------
  // Lifecycle
  // --------------------

  componentWillMount: function componentWillMount() {
    var s = this;
  },
  componentDidMount: function componentDidMount() {
    var s = this;
    var props = s.props;

    var isSupported = props.isSupported();
    if (!isSupported) {
      console.log('isSupported', isSupported);
    }
  },
  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
    var s = this;
  },
  shouldComponentUpdate: function shouldComponentUpdate(nextProps, nextState) {
    var s = this;
    return true;
  },
  componentWillUpdate: function componentWillUpdate(nextProps, nextState) {
    var s = this;
  },
  componentDidUpdate: function componentDidUpdate(prevProps, prevState) {
    var s = this;
  },
  componentWillUnmount: function componentWillUnmount() {
    var s = this;
  },


  // ------------------
  // Custom
  // ------------------

  handleHtmlLoad: function handleHtmlLoad(e) {
    var s = this;
  },
  handleEditorSubmit: function handleEditorSubmit(e) {
    var s = this;
    var props = s.props;
    var state = s.state;
    var edittingScript = state.edittingScript;
    var edittingHtml = state.edittingHtml;

    s.setState({ spinning: true });
    return new Promise(function (resolve) {
      return resolve(function (mode) {
        switch (mode) {
          case 'javascript':
          case 'jsx':
            return props.onScriptEdit({ value: edittingScript });
          case 'htmlmixed':
            return props.onHtmlEdit({ value: edittingHtml });
          default:
            return null;
        }
      }(e.mode));
    }).then(function () {
      s.setState({
        vr: s.state.vr + 1,
        spinning: false
      });
      s.clearOverlay();
    });
  },
  handleEditorChange: function handleEditorChange(e) {
    var s = this;
    var mode = e.mode;
    var value = e.value;

    switch (mode) {
      case 'javascript':
      case 'jsx':
        s.setState({ edittingScript: value });
        break;
      case 'htmlmixed':
        s.setState({ edittingHtml: value });
        break;
      default:
        break;
    }
  },
  handleEditCancel: function handleEditCancel(e) {
    var s = this;
    s.clearOverlay();
  },
  selectTab: function selectTab(tab) {
    var s = this;
    var state = s.state;
    var props = s.props;

    var deselect = state.tab === tab;
    if (deselect) {
      s.clearOverlay();
    } else {
      var overlaying = true;
      s.setState({
        tab: tab, overlaying: overlaying,
        edittingHtml: props.html,
        edittingScript: props.script
      });
    }
  },
  clearOverlay: function clearOverlay() {
    var s = this;
    s.setState({
      overlaying: false
    });
    (0, _asleep2.default)(200).then(function () {
      s.setState({ tab: null });
    });
  },


  // ------------------
  // Private
  // ------------------

  _renderTabItem: function _renderTabItem(tab, title) {
    var s = this;
    var state = s.state;
    var props = s.props;
    var errors = props.errors;

    var key = String(tab).toLowerCase();
    var className = (0, _classnames2.default)('ap-builder-tab-item', 'ap-builder-tab-item-' + key, {
      'ap-builder-tab-item-errored': errors && errors[key]
    });
    return _react2.default.createElement(
      _apemanReactTab.ApTabItem,
      { selected: state.tab === tab,
        onTap: function onTap() {
          return s.selectTab(tab);
        },
        className: className
      },
      title
    );
  }
});

exports.default = ApBuilder;
//# sourceMappingURL=data:application/json;base64,bnVsbA==