/**
 * Editor for builder
 * @class ApBuilderEditor
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _apemanReactEditor = require('apeman-react-editor');

var _apemanReactButton = require('apeman-react-button');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** @lends ApBuilderEditor */
var ApBuilderEditor = _react2.default.createClass({
  displayName: 'ApBuilderEditor',

  // --------------------
  // Specs
  // --------------------
  propTypes: {
    /** Handle for change */
    onChange: _react.PropTypes.func,
    /** Handle for cancel */
    onCancel: _react.PropTypes.func,
    /** Handle for submit */
    onSubmit: _react.PropTypes.func,
    /** Label texts */
    labels: _react.PropTypes.object,
    /** Editting source */
    src: _react.PropTypes.string,
    /** Editting type */
    mode: _react.PropTypes.string,
    /** Error message */
    error: _react.PropTypes.oneOfType([_react.PropTypes.string, _react.PropTypes.object]),
    /** Show spinner */
    spinning: _react.PropTypes.bool,

    /** Custom actions */
    actions: _react.PropTypes.array

  },

  getDefaultProps: function getDefaultProps() {
    return {
      labels: {
        cancel: 'Cancel',
        submit: 'Submit'
      },
      actions: []
    };
  },
  getInitialState: function getInitialState() {
    return {
      actionBarOpen: false
    };
  },
  render: function render() {
    var s = this;
    var state = s.state;
    var props = s.props;
    var labels = props.labels;
    var src = props.src;

    var actions = s.getActions();
    var hasActions = actions && actions.length > 0;
    return _react2.default.createElement(
      'div',
      { className: (0, _classnames2.default)('ap-builder-editor', props.className) },
      _react2.default.createElement(
        'div',
        { className: (0, _classnames2.default)('ap-builder-editor-main', {
            'ap-builder-editor-main-with-action': hasActions
          }) },
        _react2.default.createElement(_apemanReactEditor.ApEditor, { value: src,
          spinning: props.spinning,
          mode: props.mode,
          error: props.error,
          onChange: props.onChange,
          editorRef: function editorRef(editor) {
            return s.editor = editor;
          }
        }),
        hasActions ? s._renderActionBar(actions) : null
      ),
      _react2.default.createElement(
        'div',
        { className: 'ap-builder-editor-control' },
        _react2.default.createElement(
          _apemanReactButton.ApButtonGroup,
          null,
          _react2.default.createElement(
            _apemanReactButton.ApButton,
            { onTap: s.handleCancel },
            ' ',
            labels.cancel
          ),
          _react2.default.createElement(
            _apemanReactButton.ApButton,
            { primary: true, onTap: s.handleSubmit },
            ' ',
            labels.submit
          )
        )
      )
    );
  },

  // --------------------
  // Lifecycle
  // --------------------

  componentDidUpdate: function componentDidUpdate(prevProps, prevState) {
    var s = this;
    var editor = s.editor;

    if (editor) {
      s._editorRefreshTimer = setTimeout(function () {
        editor.refresh();
      }, 300);
    }
  },
  componentWillUnmount: function componentWillUnmount() {
    var s = this;
    clearTimeout(s._editorRefreshTimer);
  },


  // --------------------
  // Handle
  // --------------------

  handleCancel: function handleCancel(e) {
    var s = this;
    var props = s.props;
    var mode = props.mode;
    var src = props.src;

    if (props.onCancel) {
      props.onCancel({ mode: mode, value: src });
    }
  },
  handleSubmit: function handleSubmit(e) {
    var s = this;
    var props = s.props;
    var mode = props.mode;
    var src = props.src;

    if (props.onSubmit) {
      props.onSubmit({ mode: mode, value: src });
    }
  },
  toggleActionBar: function toggleActionBar() {
    var s = this;
    var state = s.state;

    s.setState({ actionBarOpen: !state.actionBarOpen });
  },
  getActions: function getActions() {
    var s = this;
    var props = s.props;
    var actions = props.actions;

    return actions && actions.filter(function (action) {
      var hidden = action.hidden;

      if (typeof hidden === 'function') {
        hidden = hidden();
      }
      return !hidden;
    });
  },


  // --------------------
  // Private
  // --------------------

  _renderActionBar: function _renderActionBar(actions) {
    var s = this;
    var state = s.state;
    var actionBarOpen = state.actionBarOpen;

    return _react2.default.createElement(
      'div',
      { className: (0, _classnames2.default)('ap-builder-editor-action-bar', {
          'ap-builder-editor-action-bar-open': actionBarOpen
        }) },
      _react2.default.createElement(_apemanReactButton.ApIconButton, { simple: true,
        className: (0, _classnames2.default)('ap-builder-editor-action-bar-toggle'),
        icon: actionBarOpen ? 'fa fa-toggle-down' : 'fa fa-toggle-up',
        onTap: s.toggleActionBar
      }),
      actions.map(function (action, i) {
        return _react2.default.createElement(
          _apemanReactButton.ApButton,
          { className: 'ap-builder-editor-action-item',
            simple: true,
            key: i,
            onTap: action.handle
          },
          action.text
        );
      })
    );
  },


  _editorRefreshTimer: null
});

exports.default = ApBuilderEditor;
//# sourceMappingURL=data:application/json;base64,bnVsbA==