/**
 * Frame for builder
 * @class ApBuilderFrame
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _apemanReactFrame = require('apeman-react-frame');

var _apemanReactSpinner = require('apeman-react-spinner');

var _apemanReactMixinUuid = require('apeman-react-mixin-uuid');

var _deepEqual = require('deep-equal');

var _deepEqual2 = _interopRequireDefault(_deepEqual);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _asleep = require('asleep');

var _asleep2 = _interopRequireDefault(_asleep);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var debug = (0, _debug2.default)('ap:builder:frame');

/** @lends ApBuilderFrame */
var ApBuilderFrame = _react2.default.createClass({
  displayName: 'ApBuilderFrame',

  // --------------------
  // Specs
  // --------------------
  propTypes: {
    /** Source string */
    src: _react.PropTypes.string,
    /** Handler for load event */
    onLoad: _react.PropTypes.func,
    /** Handler for script error */
    onScriptError: _react.PropTypes.func,
    /** Global variables inside iframe */
    globals: _react.PropTypes.object,
    /** Script to execute when loaded */
    script: _react.PropTypes.string,
    /** Compile script before executing */
    compile: _react.PropTypes.func,
    /** Version number */
    vr: _react.PropTypes.number
  },

  getDefaultProps: function getDefaultProps() {
    return {
      globals: {},
      compile: function compile(script) {
        return script;
      }
    };
  },
  getInitialState: function getInitialState() {
    return {
      spinning: false
    };
  },


  mixins: [_apemanReactMixinUuid.ApUUIDMixin],

  render: function render() {
    var s = this;
    var state = s.state;
    var props = s.props;
    var spinning = state.spinning;

    var id = s.getDOMId();
    return _react2.default.createElement(
      'div',
      { id: id,
        className: (0, _classnames2.default)('ap-builder-frame', props.className) },
      _react2.default.createElement(_apemanReactSpinner.ApSpinner, { enabled: spinning,
        theme: props.spinner,
        size: 'xx-large',
        className: 'ap-builder-spinner'
      }),
      _react2.default.createElement(_apemanReactFrame.ApFrame, { id: id + '-frame',
        full: true,
        onLoad: s.handleLoad,
        iframeRef: s.registerFrame })
    );
  },


  // --------------------
  // Lifecycle
  // --------------------

  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
    var s = this;
    var props = s.props;
    var iframe = s.iframe;


    var changed = props.src !== nextProps.src || props.script !== nextProps.script || props.vr !== nextProps.vr || !(0, _deepEqual2.default)(props.globals, nextProps.globals);

    if (changed) {
      s.loadSrc(nextProps.src);
    }
  },
  componentWillUnmount: function componentWillUnmount() {
    var s = this;
    clearTimeout(s._loadTimer);
  },


  // --------------------
  // Custom
  // --------------------

  getDOMId: function getDOMId() {
    var s = this;
    var props = s.props;

    return props.id || 'ap-builder-frame-' + s.uuid;
  },
  handleLoad: function handleLoad(e) {
    debug('Loaded');
    var s = this;
    var props = s.props;

    if (props.onLoad) {
      props.onLoad(e);
    }
  },
  registerFrame: function registerFrame(iframe) {
    var s = this;
    var props = s.props;

    s.iframe = iframe;
    s.loadSrc(props.src);
  },
  getFrameWindow: function getFrameWindow() {
    var s = this;
    var iframe = s.iframe;

    if (!iframe) {
      return null;
    }
    return iframe.contentWindow || window.frames[s.getDOMId() + '-frame'];
  },
  loadSrc: function loadSrc(src) {
    var s = this;
    clearTimeout(s._loadTimer);
    s._loadTimer = setTimeout(function () {
      debug('Loading src');
      var props = s.props;
      var iframe = s.iframe;

      if (!iframe) {
        return;
      }
      var parentNode = iframe.parentNode;

      iframe.src = '';

      var tasks = [function () {
        return parentNode.removeChild(iframe);
      }, function () {
        return (0, _asleep2.default)(10);
      }, // Wait for flush
      function () {
        return parentNode.appendChild(iframe);
      }, function () {
        return (0, _asleep2.default)(10);
      }, // Wait for flush
      function () {
        return new Promise(function (resolve, reject) {
          var window = s.getFrameWindow();
          if (!window) {
            resolve(true);
            return;
          }
          var document = window.document;

          var writeout = function writeout() {
            Object.assign(window, props.globals);
            document.open();
            document.write(src);
            document.close();
            resolve(true);
          };
          var completed = document.readyState === 'complete';
          if (completed) {
            writeout();
          } else {
            window.on('load', writeout);
          }
        });
      }, function () {
        return (0, _asleep2.default)(10);
      }, // Wait for flush
      function () {
        var window = s.getFrameWindow();
        var script = props.script;
        var compile = props.compile;

        if (window && script) {
          s.setState({ spinning: true });
          return Promise.resolve(compile(script));
        } else {
          return null;
        }
      }, function (script) {
        s.setState({ spinning: false }, function () {
          var window = s.getFrameWindow();
          if (window && script) {
            try {
              window.eval(script);
            } catch (err) {
              if (props.onScriptError) {
                props.onScriptError(err);
              } else {
                console.error(err);
              }
            }
          }
        });
      }];
      tasks.reduce(function (promise, task) {
        return promise.then(task);
      }, Promise.resolve(null));
    }, 100);
  },


  // --------------------
  // Private
  // --------------------

  _loadTimer: null

});
exports.default = ApBuilderFrame;
//# sourceMappingURL=data:application/json;base64,bnVsbA==